Schedulers
==========

.. currentmodule:: flowgym.schedulers

.. autosummary::
    :toctree: generated/
    :template: class.rst
    :nosignatures:

    Scheduler
    OptimalTransportScheduler
    DiffusionScheduler
    NoiseSchedule
    MemorylessNoiseSchedule
    ConstantNoiseSchedule
